

# celery_post

# host = '127.0.0.1:6001'
host = 'stq.niuguwang.com'

# -----------------------------------------------------------------------------------------
# 主要入库


# ubuntu
# MYSQL_HOST = '192.168.157.129'
# MYSQL_PORT = 3306
# MYSQL_DATABASE = 'contract_strategy'
# MYSQL_USER = 'root'
# MYSQL_PASSWORD = 'mysql'




# 生产 8.104
MYSQL_HOST = 'stq.mysql.ngw.zw.in'
MYSQL_PORT = 3306
MYSQL_DATABASE = 'contract_strategy'
MYSQL_USER = 'tjlh'
MYSQL_PASSWORD = 'tjXx^Egw3NdnLK'


# -----------------------------------------------------------------------------------------
LOGFLAG = True
# LOGFLAG = False





